AC_DEFUN([ARK_PATH_QT4], [
	AC_ARG_WITH(qt, AS_HELP_STRING([--with-qt=DIR], [Location of Qt 4.x]))
	if test "$with_qt" = "yes" -o "$with_qt" = "no"; then
		with_qt=""
	fi
	AC_ARG_ENABLE(qt_debug, AS_HELP_STRING([--enable-qt-debug], [Build with debugging versions of Qt libs]))
	AC_MSG_CHECKING([for Qt 4.x])
	LibDir="lib"
	if uname -m |grep -q 64 && test -d /usr/lib64; then
		LibDir="lib64"
	fi
	for dir in $with_qt $QTDIR /usr/$LibDir/qt4 /opt/qt4 /usr/$LibDir/qt /opt/qt; do
		if test -e $dir/lib/libQtCore.so; then
			ark_cv_lib_qt_dir="$dir"
			break
		fi
	done
	if test "$ark_cv_lib_qt_dir" = "no"; then
		AC_MSG_RESULT([not found])
	else
		AC_MSG_RESULT([$ark_cv_lib_qt_dir])
		QT="$ark_cv_lib_qt_dir"
		AC_SUBST([QT])
	fi
])

AC_DEFUN([ARK_QT4_CORE], [
	AC_REQUIRE([ARK_PATH_QT4])
	CPPFLAGS="$CPPFLAGS -D_REENTRANT -DQT_SHARED -I$ark_cv_lib_qt_dir/include/QtCore"
	if test "$enable_qt_debug" = "no"; then
		CPPFLAGS="$CPPFLAGS -DQT_NO_DEBUG"
	fi
	LDFLAGS="$LDFLAGS -L$ark_cv_lib_qt_dir/lib"
])

AC_DEFUN([ARK_QT4_GUI], [
	AC_REQUIRE([ARK_QT4_CORE])
	CPPFLAGS="$CPPFLAGS -I$ark_cv_lib_qt_dir/include/QtGui"
])

AC_DEFUN([ARK_QT4_XML], [
	AC_REQUIRE([ARK_QT4_CORE])
	CPPFLAGS="$CPPFLAGS -I$ark_cv_lib_qt_dir/include/QtXml"
])

AC_DEFUN([ARK_QT4_DBUS], [
	AC_REQUIRE([ARK_QT4_XML])
	CPPFLAGS="$CPPFLAGS -I$ark_cv_lib_qt_dir/include/QtDBus"
])

AC_DEFUN([ARK_QT4_NETWORK], [
	AC_REQUIRE([ARK_QT4_CORE])
	CPPFLAGS="$CPPFLAGS -I$ark_cv_lib_qt_dir/include/QtNetwork"
])

AC_DEFUN([ARK_QT4_OPENGL], [
	AC_REQUIRE([ARK_QT4_GUI])
	CPPFLAGS="$CPPFLAGS -I$ark_cv_lib_qt_dir/include/QtOpenGL"
])

AC_DEFUN([ARK_QT4_SCRIPT], [
	AC_REQUIRE([ARK_QT4_CORE])
	CPPFLAGS="$CPPFLAGS -I$ark_cv_lib_qt_dir/include/QtScript"
])

AC_DEFUN([ARK_QT4_SQL], [
	AC_REQUIRE([ARK_QT4_CORE])
	CPPFLAGS="$CPPFLAGS -I$ark_cv_lib_qt_dir/include/QtSql"
])

AC_DEFUN([ARK_QT4_SVG], [
	AC_REQUIRE([ARK_QT4_GUI])
	AC_REQUIRE([ARK_QT4_XML])
	CPPFLAGS="$CPPFLAGS -I$ark_cv_lib_qt_dir/include/QtSvg"
])

AC_DEFUN([ARK_QT4_TEST], [
	AC_REQUIRE([ARK_QT4_CORE])
	CPPFLAGS="$CPPFLAGS -I$ark_cv_lib_qt_dir/include/QtTest"
])

AC_DEFUN([ARK_QT4_COMPAT], [
	AC_REQUIRE([ARK_QT4_CORE])
	AC_REQUIRE([ARK_QT4_GUI])
	AC_REQUIRE([ARK_QT4_NETWORK])
	AC_REQUIRE([ARK_QT4_SQL])
	AC_REQUIRE([ARK_QT4_XML])
	CPPFLAGS="$CPPFLAGS -I$ark_cv_lib_qt_dir/include/Qt3Support"
])

AC_DEFUN([ARK_QT4_DESIGNER], [
	AC_REQUIRE([ARK_QT4_CORE])
	AC_REQUIRE([ARK_QT4_GUI])
	AC_REQUIRE([ARK_QT4_NETWORK])
	AC_REQUIRE([ARK_QT4_XML])
	CPPFLAGS="$CPPFLAGS -I$ark_cv_lib_qt_dir/include/QtDesigner"
])

AC_DEFUN([ARK_QT_WEBKIT], [
	AC_REQUIRE([ARK_QT4_GUI])
	AC_MSG_CHECKING([for WebKit])
	SAVE_CPPFLAGS="$CPPFLAGS"
	CPPFLAGS="$CPPFLAGS -I$ark_cv_lib_qt_dir/include/QtWebKit"
	AC_LANG_PUSH([C++])
	AC_COMPILE_IFELSE([
		#include <qwebpage.h>
	], [found=yes], [found=no])
	AC_MSG_RESULT([$found])
	AC_LANG_POP
	if test "$found" = "yes"; then
		AC_DEFINE([HAVE_WEBKIT], [1], [Define if you have WebKit])
	else
		CPPFLAGS="$SAVE_CPPFLAGS"
	fi
])

AC_DEFUN([ARK_QT4], [
	AC_REQUIRE([ARK_QT4_CORE])
	AC_REQUIRE([ARK_QT4_GUI])
	AC_REQUIRE([ARK_QT4_XML])
	AC_REQUIRE([ARK_QT4_NETWORK])
	AC_REQUIRE([ARK_QT4_OPENGL])
	AC_REQUIRE([ARK_QT4_DBUS])
	AC_REQUIRE([ARK_QT4_SCRIPT])
	AC_REQUIRE([ARK_QT4_SQL])
	AC_REQUIRE([ARK_QT4_SVG])
	AC_REQUIRE([ARK_QT4_TEST])
])

AC_DEFUN([ARK_PATH_KDE4], [
	AC_ARG_WITH(kde, AS_HELP_STRING([--with-kde=DIR], [Location of KDE 4.x]))
	if test "$with_kde" = "yes"; then
		with_kde=""
	fi
	AC_MSG_CHECKING([for KDE 4.x])
	if test "$with_kde" = "no"; then
		AC_MSG_RESULT([disabled by user])
	else
		ark_cv_lib_kde_dir=no
		if uname -m |grep -q 64 && test -d /usr/lib64; then
			LibDir="lib64"
		fi
		for dir in $with_kde /opt/kde-4.0 /opt/kde-4.0.0 /opt/kde4 /usr; do
			if test -e $dir/$LibDir/libkhtml.so.5; then
				ark_cv_lib_kde_dir="$dir"
				break
			fi
		done
		if test "$ark_cv_lib_kde_dir" = "no"; then
			with_kde=no
			AC_MSG_RESULT([not found])
		else
			AC_DEFINE_UNQUOTED([WITH_KDE], [1], [Define to use KDE])
			AC_MSG_RESULT([$ark_cv_lib_kde_dir])
			KDE="$ark_cv_lib_kde_dir"
			if test "$KDE" = "/usr"; then
				KDE_INCLUDES="-I/usr/include/kde"
			else
				KDE_INCLUDES="-I$KDE/include"
			fi
			AC_SUBST([KDE])
			AC_SUBST([KDE_INCLUDES])
			KDECORE="-L$KDE/lib -Wl,--rpath -Wl,$KDE/lib -lkdecore"
			KDEUI="$KDECORE -lkdeui"
			KHTML="$KDECORE -lkhtml"
			AC_SUBST([KDECORE])
			AC_SUBST([KHTML])
			AC_SUBST([KDEUI])
		fi
	fi
	AM_CONDITIONAL(WITH_KDE, test "$with_kde" != "no")
])

AC_DEFUN([ARK_PATH_QTEXT], [
	AC_MSG_CHECKING([for Qt Extension library])
	AC_LANG_PUSH([C++])
	qtextdir=""
	for i in ${includedir} ${prefix}/include /usr/local/include /usr/include; do
		if test -d $i/qtext; then
			qtextdir="$i/qtext"
			break
		fi
	done
	if test -z "$qtextdir"; then
		AC_MSG_RESULT([not found])
	else
		AC_MSG_RESULT([headers in $qtextdir])
		CPPFLAGS="$CPPFLAGS -I$qtextdir"
	fi
	AC_LANG_POP
])

AC_DEFUN([ARK_QT_PLATFORM], [
	AC_REQUIRE([ARK_QT4_CORE])
	AC_MSG_CHECKING([Qt platform])
	platform=unknown
	AC_COMPILE_IFELSE([
		#include <qglobal.h>
		#ifndef Q_WS_X11
		#error Not X11
		#endif
	], [platform=X11], [])
	if test "$platform" = "unknown"; then
		AC_COMPILE_IFELSE([
			#include <qglobal.h>
			#ifndef Q_WS_QWS
			#error Not Qtopia
			#endif
		], [platform=Qtopia], [])
	fi
	if test "$platform" = "unknown"; then
		AC_COMPILE_IFELSE([
			#include <qglobal.h>
			#ifndef Q_WS_MACX
			#error Not OSX
			#endif
		], [platform=OSX], [])
	fi
	if test "$platform" = "unknown"; then
		AC_COMPILE_IFELSE([
			#include <qglobal.h>
			#ifndef Q_WS_MAC9
			#error Not OS9
			#endif
		], [platform=OS9], [])
	fi
	if test "$platform" = "unknown"; then
		AC_COMPILE_IFELSE([
			#include <qglobal.h>
			#ifndef Q_WS_WIN32
			#error No dirty Nazi junk
			#endif
		], [platform=Win32], [])
	fi
	AM_CONDITIONAL([QT_X11], [test "$platform" = "X11"])
	AM_CONDITIONAL([QTOPIA], [test "$platform" = "Qtopia"])
	AM_CONDITIONAL([QT_OSX], [test "$platform" = "OSX"])
	AM_CONDITIONAL([QT_OS9], [test "$platform" = "OS9"])
	AM_CONDITIONAL([QT_WIN32], [test "$platform" = "Win32"])
	AC_MSG_RESULT([$platform])
])
